@@ -37,27 +37,27 @@ type Decoder interface {
 	DecodeConfig(r io.Reader) (image.Config, error)
 }
 
-// Encoder defines the encoding of an image format.
-type Encoder interface {
-	Encode(w io.Writer, src image.Image) error
-}
-
 type ToEncoder interface {
 	EncodeTo(conf ImageConfig, w io.Writer, src image.Image) error
 }
 
-// CodecStdlib defines both decoding and encoding of an image format as defined by the standard library.
-type CodecStdlib interface {
+// EncoderWithOptions defines the encoding of an image format with the given options.
+type Encoder interface {
+	Encode(w io.Writer, src image.Image, options map[string]any) error
+}
+
+// EncodeDecoder defines both decoding and encoding of an image format as defined by the standard library.
+type EncodeDecoder interface {
 	Decoder
 	Encoder
 }
 
 // Codec is a generic image codec supporting multiple formats.
 type Codec struct {
-	webp CodecStdlib
+	webp EncodeDecoder
 }
 
-func newCodec(webp CodecStdlib) *Codec {
+func newCodec(webp EncodeDecoder) *Codec {
 	return &Codec{webp: webp}
 }
 
@@ -123,7 +123,12 @@ func (d *Codec) EncodeTo(conf ImageConfig, w io.Writer, img image.Image) error {
 	case BMP:
 		return bmp.Encode(w, img)
 	case WEBP:
-		return d.webp.Encode(w, img)
+		opts := map[string]any{
+			"compression": conf.Compression,
+			"quality":     conf.Quality,
+			"hint":        conf.Hint,
+		}
+		return d.webp.Encode(w, img, opts)
 	default:
 		return errors.New("format not supported")
 	}
